@@ -471,7 +471,7 @@ class QRydBackend(Backend):
 class QRydEmuCloudcompSquare(QRydBackend):
     """Backend for accessing a specific emulator.
 
-    The emulator simulates *30 qubits* arranged in a *5x6 square lattice* with
+    The emulator simulates *30 ideal qubits* arranged in a *5x6 square lattice* with
     nearest-neighbor connectivity. Quantum circuits are compiled to the gate set and
     connectivity of the Rydberg platform on our servers after submitting the
     circuits to QRydDemo's infrastructure.
@@ -578,7 +578,7 @@ class QRydEmuCloudcompSquare(QRydBackend):
 class QRydEmuCloudcompTriangle(QRydBackend):
     """Backend for accessing a specific emulator.
 
-    The emulator simulates *30 qubits* arranged in a *triangle lattice* with
+    The emulator simulates *30 ideal qubits* arranged in a *triangle lattice* with
     nearest-neighbor connectivity. Quantum circuits are compiled to the gate set and
     connectivity of the Rydberg platform on our servers after submitting the
     circuits to QRydDemo's infrastructure.
@@ -685,7 +685,7 @@ class QRydEmuCloudcompTriangle(QRydBackend):
 class QRydEmuLocalcompSquare(QRydBackend):
     """Backend for accessing a specific emulator.
 
-    The emulator simulates *30 qubits* arranged in a *5x6 square lattice* with
+    The emulator simulates *30 ideal qubits* arranged in a *5x6 square lattice* with
     nearest-neighbor connectivity. Quantum circuits are compiled to the gate set and
     connectivity of the Rydberg platform by Qiskit.
 
@@ -767,7 +767,7 @@ class QRydEmuLocalcompSquare(QRydBackend):
 class QRydEmuLocalcompTriangle(QRydBackend):
     """Backend for accessing a specific emulator.
 
-    The emulator simulates *30 qubits* arranged in a *triangle lattice* with
+    The emulator simulates *30 ideal qubits* arranged in a *triangle lattice* with
     nearest-neighbor connectivity. Quantum circuits are compiled to the gate set and
     connectivity of the Rydberg platform by Qiskit.
 
